@@ -1,20 +1,6 @@
-/* Copyright (C) 2014-2022 Greenbone Networks GmbH
+/* SPDX-FileCopyrightText: 2014-2023 Greenbone AG
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -121,6 +107,10 @@ static int
 osp_send_command (osp_connection_t *, entity_t *, const char *, ...)
   __attribute__ ((__format__ (__printf__, 3, 4)));
 
+static int
+osp_send_command_str (osp_connection_t *, gchar **, const char *, ...)
+  __attribute__ ((__format__ (__printf__, 3, 4)));
+
 /**
  * @brief Open a new connection to an OSP server.
  *
@@ -143,6 +133,13 @@ osp_connection_new (const char *host, int port, const char *cacert,
       struct sockaddr_un addr;
       int len;
 
+      if (strlen (host) >= sizeof (addr.sun_path))
+        {
+          g_warning ("%s: given host / socket path too long (%zu > %zu bytes)",
+                     __func__, strlen (host), sizeof (addr.sun_path) - 1);
+          return NULL;
+        }
+
       connection = g_malloc0 (sizeof (*connection));
       connection->socket = socket (AF_UNIX, SOCK_STREAM, 0);
       if (connection->socket == -1)
@@ -153,7 +150,7 @@ osp_connection_new (const char *host, int port, const char *cacert,
 
       addr.sun_family = AF_UNIX;
       memset (addr.sun_path, 0, sizeof (addr.sun_path));
-      memcpy (addr.sun_path, host, sizeof (addr.sun_path) - 1);
+      memcpy (addr.sun_path, host, strlen (host));
       len = strlen (addr.sun_path) + sizeof (addr.sun_family);
       if (connect (connection->socket, (struct sockaddr *) &addr, len) == -1)
         {
@@ -230,6 +227,60 @@ out:
   return rc;
 }
 
+/**
+ * @brief Send a command to an OSP server.
+ *
+ * @param[in]   connection  Connection to OSP server.
+ * @param[out]  response    Response from OSP server.
+ * @param[in]   fmt         OSP Command to send.
+ *
+ * @return 0 and response, 1 if error.
+ */
+static int
+osp_send_command_str (osp_connection_t *connection, gchar **str,
+                      const char *fmt, ...)
+{
+  va_list ap;
+  int rc;
+  gvm_connection_t conn;
+
+  rc = 1;
+  *str = NULL;
+
+  va_start (ap, fmt);
+
+  if (!connection || !fmt)
+    goto out;
+
+  if (*connection->host == '/')
+    {
+      if (gvm_socket_vsendf (connection->socket, fmt, ap) == -1)
+        goto out;
+      conn.tls = 0;
+    }
+  else
+    {
+      if (gvm_server_vsendf (&connection->session, fmt, ap) == -1)
+        goto out;
+      conn.tls = 1;
+    }
+
+  conn.socket = connection->socket;
+  conn.session = connection->session;
+  conn.host_string = connection->host;
+  conn.port = connection->port;
+
+  if (read_text_c (&conn, str))
+    goto out;
+
+  rc = 0;
+
+out:
+  va_end (ap);
+
+  return rc;
+}
+
 /**
  * @brief Close a connection to an OSP server.
  *
@@ -617,6 +668,45 @@ osp_get_vts_ext (osp_connection_t *connection, osp_get_vts_opts_t opts,
   return 0;
 }
 
+/**
+ * @brief Get filtered set of VTs from an OSP server.
+ *
+ * @param[in]   connection  Connection to an OSP server.
+ * @param[in]   opts        Struct containing the options to apply.
+ * @param[out]  vts         VTs.
+ *
+ * @return 0 if success, 1 if error.
+ */
+int
+osp_get_vts_ext_str (osp_connection_t *connection, osp_get_vts_opts_t opts,
+                     gchar **str)
+{
+  if (!connection)
+    return 1;
+
+  if (str == NULL)
+    return 1;
+
+  if (opts.version_only == 1)
+    {
+      if (osp_send_command_str (connection, str, "<get_vts version_only='1'/>"))
+        return 1;
+      return 0;
+    }
+
+  if (opts.filter)
+    {
+      if (osp_send_command_str (connection, str, "<get_vts filter='%s'/>",
+                                opts.filter))
+        return 1;
+      return 0;
+    }
+
+  if (osp_send_command_str (connection, str, "<get_vts/>"))
+    return 1;
+  return 0;
+}
+
 /**
  * @brief Delete a scan from an OSP server.
  *
