@@ -1,20 +1,6 @@
-/* Copyright (C) 2009-2022 Greenbone Networks GmbH
+/* SPDX-FileCopyrightText: 2009-2023 Greenbone AG
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -147,6 +133,9 @@ read_string (gnutls_session_t *, GString **);
 int
 read_string_c (gvm_connection_t *, GString **);
 
+int
+read_text_c (gvm_connection_t *, char **);
+
 int
 parse_entity (const char *, entity_t *);
 
@@ -186,4 +175,10 @@ element_t element_first_child (element_t);
 
 element_t element_next (element_t);
 
+gchar *
+element_to_string (element_t element);
+
+void
+print_element_to_string (element_t element, GString *string);
+
 #endif /* not _GVM_XMLUTILS_H */
